score_factory
=================================================

.. currentmodule:: skchange.scores

.. autofunction:: score_factory

.. include:: skchange.scores.score_factory.examples

.. raw:: html

    <div class="clearer"></div>